@@ -1,4 +1,4 @@
-package Pcore::Selenium v0.8.0;
+package Pcore::Selenium v0.8.1;
 
 use Pcore -dist, -class;
 
@@ -15,7 +15,7 @@ Pcore::Selenium
 =head1 SYNOPSIS
 
     # create handle
-    my $h = Pcore::Handle->new('selenium://127.0.0.1:4444');
+    my $h = P->handle('selenium://127.0.0.1:4444');
 
 =head1 DESCRIPTION
 
